@@ -26,6 +26,12 @@
 #include <sys/types.h>
 #include <sys/wait.h>
 
+#ifdef __clang__
+#define ZERO_INIT {}
+#else
+#define ZERO_INIT {0}
+#endif
+
 extern char **environ;
 
 static GMutex id_counter_lock;
@@ -354,7 +360,7 @@ gboolean bd_utils_exec_and_report_progress (const gchar **argv, const BDExtraArg
     GIOStatus io_status = G_IO_STATUS_NORMAL;
     guint i = 0;
     guint8 completion = 0;
-    GPollFD fds[2] = {{0}, {0}};
+    GPollFD fds[2] = {ZERO_INIT, ZERO_INIT};
     gboolean out_done = FALSE;
     gboolean err_done = FALSE;
     GString *stdout_data = g_string_new (NULL);
@@ -802,3 +808,13 @@ gboolean bd_utils_echo_str_to_file (const gchar *str, const gchar *file_path, GE
     g_io_channel_unref (out_file);
     return TRUE;
 }
+
+/**
+ * bd_utils_log:
+ * @level: log level
+ * @msg: log message
+ */
+void bd_utils_log (gint level, const gchar *msg) {
+    if (log_func)
+        log_func (level, msg);
+}
